@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0203';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -96,7 +96,8 @@ sub generate {
             $n->en_eq('sharp');
         }
         my $y = $n->format('isobase');
-        if (
+        if (($scale eq 'major' || $scale eq 'minor')
+            && (
             ($flavor =~ /[#b]5/ && ($x eq $tones[4] || $y eq $tones[4]))
             ||
             ($flavor =~ /7/ && $flavor !~ /[Mm]7/ && ($x eq $tones[6] || $y eq $tones[6]))
@@ -108,6 +109,7 @@ sub generate {
             ($flavor =~ /dim/ && ($x eq $tones[6] || $y eq $tones[6]))
             ||
             ($flavor =~ /aug/ && ($x eq $tones[6] || $y eq $tones[6]))
+            )
         ) {
             print "\tDROP: $x\n" if $self->verbose;
             next;
@@ -156,7 +158,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0202
+version 0.0203
 
 =head1 SYNOPSIS
 
